@@ -6,7 +6,7 @@ use 5.014;
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 use Carp qw(confess cluck);
 use DateTime;
@@ -46,7 +46,7 @@ sub new {
 	my $res_st = $ua->get( $self->{iris_base} . '/station/' . $opt{station} );
 
 	if ( $res_st->is_error ) {
-		$self->{errstr} = 'Failed to fetch station data: Server returned '
+		$self->{errstr} = 'Failed to fetch station data: '
 		  . $res_st->status_line;
 		return $self;
 	}
@@ -54,6 +54,9 @@ sub new {
 	my $xml_st = XML::LibXML->load_xml( string => $res_st->decoded_content );
 
 	$self->{nodes}{station} = ( $xml_st->findnodes('//station') )[0];
+	# TODO parse 'meta' and maybe 'p' flags
+	# They're optional pointers to related platforms. For instance
+	# Berlin Hbf/BL -> Berlin HBf (tief), Berlin Hbf (S), ...
 
 	if ( not $self->{nodes}{station} ) {
 		$self->{errstr}
@@ -185,7 +188,7 @@ sub get_timetable {
 	}
 
 	if ( $res->is_error ) {
-		$self->{warnstr} = 'Failed to fetch a schedule part: Server returned '
+		$self->{warnstr} = 'Failed to fetch a schedule part: '
 		  . $res->status_line;
 		return $self;
 	}
@@ -213,7 +216,7 @@ sub get_realtime {
 	}
 
 	if ( $res->is_error ) {
-		$self->{warnstr} = 'Failed to fetch realtime data: Server returned '
+		$self->{warnstr} = 'Failed to fetch realtime data: '
 		  . $res->status_line;
 		return $self;
 	}
@@ -275,6 +278,7 @@ sub get_realtime {
 				type      => $e_ref->getAttribute('c'),    # S/ICE/ERB/...
 				line_no   => $e_ref->getAttribute('l'),    # 1 -> S1, ...
 				unknown_o => $e_ref->getAttribute('o'),    # owner: 03/80/R2/...
+				# TODO ps='a' -> rerouted and normally unscheduled train?
 			);
 		}
 		if ($e_ar) {
@@ -286,6 +290,7 @@ sub get_realtime {
 				sched_route_pre => $e_ar->getAttribute('ppth'),
 				status          => $e_ar->getAttribute('cs'),
 				status_since    => $e_ar->getAttribute('clt'),
+				# TODO ps='a' -> rerouted and normally unscheduled train?
 			);
 		}
 		if ($e_dp) {
@@ -402,7 +407,7 @@ Travel::Status::DE::IRIS - Interface to IRIS based web departure monitors.
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =head1 DESCRIPTION
 
