@@ -15,7 +15,7 @@ use List::Compare;
 use List::MoreUtils qw(none uniq firstval);
 use Scalar::Util qw(weaken);
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 my %translation = (
 	2  => 'Polizeiliche Ermittlung',
@@ -68,7 +68,7 @@ my %translation = (
 	63 => 'Technische Untersuchung am Zug',
 	64 => 'Weichenstörung',
 	65 => 'Erdrutsch',
-	70 => 'Kein WLAN(?)', # ?
+	70 => 'Kein WLAN',
 	73 => 'Mehrzweckabteil vorne',
 	74 => 'Mehrzweckabteil hinten',
 	75 => '1. Klasse vorne',
@@ -93,6 +93,7 @@ my %translation = (
 	97 => 'Der Zug ist überbesetzt', # r 96
 	98 => 'Sonstige Qualitätsmängel',
 	99 => 'Verzögerungen im Betriebsablauf',
+	900 => 'Anschlussbus wartet(?)',
 );
 
 Travel::Status::DE::IRIS::Result->mk_ro_accessors(
@@ -753,7 +754,7 @@ arrival/departure received by Travel::Status::DE::IRIS
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =head1 DESCRIPTION
 
@@ -1212,7 +1213,7 @@ Source: correlation between IRIS and DB RIS (bahn.de).
 
 =item q 70 : "Kein WLAN"
 
-Uncertain. Source: correlation between IRIS and DB RIS (bahn.de).
+Source: correlation between IRIS and DB RIS (bahn.de).
 
 =item q 73 : "Mehrzweckabteil vorne"
 
@@ -1318,6 +1319,10 @@ Might also mean "Kein rollstuhlgerechter Wagen" (source: frubi).
 
 =item d 99 : "VerzE<ouml>gerungen im Betriebsablauf"
 
+=item f 900 : "Anschlussbus wartet(?)"
+
+Verified by correlation. Not sure yet.
+
 =back
 
 =head1 DIAGNOSTICS
